@@ -1,12 +1,12 @@
 from .avl_tree import AVLTree, AVLNode
 from .binary_search_tree import BinarySearchTree
 from .binary_tree import BinaryTree, TreeNode
-from .max_heap_tree import MaxHeapTree
+from .heap_tree import HeapTree
 from .min_heap_tree import MinHeapTree
 
 __all__ = [
     "BinaryTree", "TreeNode",
     "BinarySearchTree",
     "AVLTree", "AVLNode",
-    "MaxHeapTree", "MinHeapTree"
+    "HeapTree", "MinHeapTree"
 ]
